package com.ruoyi.project.patrol.dev.service;

import java.util.List;
import com.ruoyi.project.patrol.dev.domain.TDevEarplug;

/**
 * 耳塞分配器Service接口
 * 
 * @author admin
 * @date 2023-11-08
 */
public interface ITDevEarplugService 
{
    /**
     * 查询耳塞分配器
     * 
     * @param id 耳塞分配器主键
     * @return 耳塞分配器
     */
    public TDevEarplug selectTDevEarplugById(Long id);

    /**
     * 查询耳塞分配器列表
     * 
     * @param tDevEarplug 耳塞分配器
     * @return 耳塞分配器集合
     */
    public List<TDevEarplug> selectTDevEarplugList(TDevEarplug tDevEarplug);

    /**
     * 新增耳塞分配器
     * 
     * @param tDevEarplug 耳塞分配器
     * @return 结果
     */
    public int insertTDevEarplug(TDevEarplug tDevEarplug);

    /**
     * 修改耳塞分配器
     * 
     * @param tDevEarplug 耳塞分配器
     * @return 结果
     */
    public int updateTDevEarplug(TDevEarplug tDevEarplug);

    /**
     * 批量删除耳塞分配器
     * 
     * @param ids 需要删除的耳塞分配器主键集合
     * @return 结果
     */
    public int deleteTDevEarplugByIds(Long[] ids);

    /**
     * 删除耳塞分配器信息
     * 
     * @param id 耳塞分配器主键
     * @return 结果
     */
    public int deleteTDevEarplugById(Long id);
}
